import React from 'react';
import { PopoverProps } from '@radix-ui/react-popover';
/**
 * Props shared by both single and multi combobox
 */
export type SharedComboboxProps = {
    /**
     * String displayed before anything is selected
     */
    placeholder?: string;
    /**
     * A list of option the user can select from. `value` needs to be unique.
     */
    options: OptionType[];
    /**
     * Disable the combobox
     */
    disabled?: boolean;
} & Omit<React.ButtonHTMLAttributes<HTMLButtonElement>, 'value' | 'defaultValue'>;
type OptionType = {
    value: any;
    label: any;
};
/**
 * Props used exclusively by the single combobox
 */
export interface ComboboxProps {
    /**
     * A value that matches a value in the `options`
     */
    defaultValue?: any;
    /**
     * For controlling the value of the combobox externally.
     */
    value?: any;
    /**
     * Callback called on value select
     */
    onSelect?: (option: OptionType) => void;
    /**
     * Callback called whenever the selected value changes
     */
    onValueChange?: (value: OptionType | undefined) => void;
}
/**
 * Props used exclusively by the single combobox
 */
export interface ComboboxMultiProps {
    defaultValue?: any[];
    /**
     * For controlling the value of the combobox externally.
     */
    value?: any[];
    /**
     * Callback called on value select
     */
    onSelect?: (option: OptionType) => void;
    /**
     * Callback called whenever the selected values change
     */
    onValueChange?: (value: OptionType[]) => void;
}
/**
 * A combobox element that allows selecting multiple values
 */
declare const ComboboxMulti: React.ForwardRefExoticComponent<ComboboxMultiProps & {
    /**
     * String displayed before anything is selected
     */
    placeholder?: string | undefined;
    /**
     * A list of option the user can select from. `value` needs to be unique.
     */
    options: OptionType[];
    /**
     * Disable the combobox
     */
    disabled?: boolean | undefined;
} & Omit<React.ButtonHTMLAttributes<HTMLButtonElement>, "value" | "defaultValue"> & React.RefAttributes<HTMLButtonElement>>;
interface ComboboxPrimitiveProps {
    buttonRender: React.ReactNode;
    handleSelect: (option: OptionType) => void;
    value: OptionType | OptionType[] | undefined;
    open: boolean;
    onOpenChange: PopoverProps['onOpenChange'];
    handleIconOpacity: (option: OptionType) => boolean;
}
/**
 * This is a combobox template, it helps with not duplicating tags and component logic
 * while still being customisable enough for both Single and Multi combobox to use it
 */
export declare const ComboboxPrimtive: React.ForwardRefExoticComponent<ComboboxPrimitiveProps & {
    /**
     * String displayed before anything is selected
     */
    placeholder?: string | undefined;
    /**
     * A list of option the user can select from. `value` needs to be unique.
     */
    options: OptionType[];
    /**
     * Disable the combobox
     */
    disabled?: boolean | undefined;
} & Omit<React.ButtonHTMLAttributes<HTMLButtonElement>, "value" | "defaultValue"> & React.RefAttributes<HTMLButtonElement>>;
declare const Combobox: React.ForwardRefExoticComponent<ComboboxProps & {
    /**
     * String displayed before anything is selected
     */
    placeholder?: string | undefined;
    /**
     * A list of option the user can select from. `value` needs to be unique.
     */
    options: OptionType[];
    /**
     * Disable the combobox
     */
    disabled?: boolean | undefined;
} & Omit<React.ButtonHTMLAttributes<HTMLButtonElement>, "value" | "defaultValue"> & React.RefAttributes<HTMLButtonElement & {
    Multi: typeof ComboboxMulti;
}>> & {
    Multi: React.ForwardRefExoticComponent<ComboboxMultiProps & {
        /**
         * String displayed before anything is selected
         */
        placeholder?: string | undefined;
        /**
         * A list of option the user can select from. `value` needs to be unique.
         */
        options: OptionType[];
        /**
         * Disable the combobox
         */
        disabled?: boolean | undefined;
    } & Omit<React.ButtonHTMLAttributes<HTMLButtonElement>, "value" | "defaultValue"> & React.RefAttributes<HTMLButtonElement>>;
};
export { Combobox };
